# npc_samstim

Tools for processing stim data from Sam's DynamicRoutingTask, compatible with data in the cloud.

[![PyPI](https://img.shields.io/pypi/v/npc_samstim.svg?label=PyPI&color=blue)](https://pypi.org/project/npc_samstim/)
[![Python version](https://img.shields.io/pypi/pyversions/npc_samstim)](https://pypi.org/project/npc_samstim/)

[![Coverage](https://img.shields.io/codecov/c/github/AllenInstitute/npc_samstim?logo=codecov)](https://app.codecov.io/github/AllenInstitute/npc_samstim)
[![CI/CD](https://img.shields.io/github/actions/workflow/status/AllenInstitute/npc_samstim/publish.yml?label=CI/CD&logo=github)](https://github.com/AllenInstitute/npc_samstim/actions/workflows/publish.yml)
[![GitHub issues](https://img.shields.io/github/issues/AllenInstitute/npc_samstim?logo=github)](https://github.com/AllenInstitute/npc_samstim/issues)

# Usage
```bash
conda create -n npc_samstim python>=3.9
conda activate npc_samstim
pip install npc_samstim
```

## Python
```python
>>> import npc_samstim
```

# Development
See instructions in https://github.com/AllenInstitute/npc_samstim/CONTRIBUTING.md and the original template: https://github.com/AllenInstitute/copier-pdm-npc/blob/main/README.md